MatchMakerMonitoring
==========================================

.. currentmodule:: alfred3_interact.page

.. autoclass:: MatchMakerMonitoring
   :show-inheritance:




   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
      :toctree:




      ~MatchMakerMonitoring.added_to_experiment


      ~MatchMakerMonitoring.added_to_section


      ~MatchMakerMonitoring.append


      ~MatchMakerMonitoring.close


      ~MatchMakerMonitoring.custom_move


      ~MatchMakerMonitoring.durations


      ~MatchMakerMonitoring.first_duration


      ~MatchMakerMonitoring.last_duration


      ~MatchMakerMonitoring.on_close


      ~MatchMakerMonitoring.on_each_hide


      ~MatchMakerMonitoring.on_each_show


      ~MatchMakerMonitoring.on_exp_access


      ~MatchMakerMonitoring.on_first_hide


      ~MatchMakerMonitoring.on_first_show


      ~MatchMakerMonitoring.position_in_section


      ~MatchMakerMonitoring.prepare_web_widget


      ~MatchMakerMonitoring.save_data


      ~MatchMakerMonitoring.showif


      ~MatchMakerMonitoring.uptree


      ~MatchMakerMonitoring.validate


      ~MatchMakerMonitoring.visible







   .. rubric:: Attributes

   .. autosummary::
      :template: autosummary/attribute.rst
      :toctree:


         ~MatchMakerMonitoring.access_level
         ~MatchMakerMonitoring.all_elements
         ~MatchMakerMonitoring.all_input_elements
         ~MatchMakerMonitoring.background_color
         ~MatchMakerMonitoring.data
         ~MatchMakerMonitoring.elements
         ~MatchMakerMonitoring.exp
         ~MatchMakerMonitoring.experiment
         ~MatchMakerMonitoring.filled_input_elements
         ~MatchMakerMonitoring.fixed_width
         ~MatchMakerMonitoring.footer_text
         ~MatchMakerMonitoring.has_been_shown
         ~MatchMakerMonitoring.header_color
         ~MatchMakerMonitoring.input_elements
         ~MatchMakerMonitoring.instance_log
         ~MatchMakerMonitoring.is_closed
         ~MatchMakerMonitoring.minimum_display_time
         ~MatchMakerMonitoring.minimum_display_time_msg
         ~MatchMakerMonitoring.must_be_shown
         ~MatchMakerMonitoring.name
         ~MatchMakerMonitoring.parent
         ~MatchMakerMonitoring.parent_name
         ~MatchMakerMonitoring.prefix_element_names
         ~MatchMakerMonitoring.progress
         ~MatchMakerMonitoring.responsive_width
         ~MatchMakerMonitoring.section
         ~MatchMakerMonitoring.short_tree
         ~MatchMakerMonitoring.should_be_shown
         ~MatchMakerMonitoring.subtitle
         ~MatchMakerMonitoring.tag
         ~MatchMakerMonitoring.title
         ~MatchMakerMonitoring.tree
         ~MatchMakerMonitoring.uid
         ~MatchMakerMonitoring.unlinked_data
         ~MatchMakerMonitoring.updated_elements
         ~MatchMakerMonitoring.vargs
